==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/test/ui/internal/editor/form/util/NodeGeneralInfoSection.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.internal.editor.form.util;

import org.eclipse.hyades.models.common.common.CMNNodeInstance;
import org.eclipse.hyades.models.common.common.CMNNodeType;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.test.ui.internal.editor.form.base.FormWidgetFactory;
import org.eclipse.hyades.ui.internal.util.GridDataUtil;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.widgets.Composite;

/**
 * This class implements a general infomation section of an {@link org.eclipse.hyades.models.common.configuration.CFGLocation} 
 * resource editor that provides an editing field for <i>hostname</i>.
 *  
 * @author bjiang
 * @since  1.3
 */
public class NodeGeneralInfoSection extends GeneralInfoSection //implements SelectionListener
{
	private StyledText hostnameText;
	//private Button	setDefaultCheckButton;
	
	/**
	 * @param editorForm
	 */
	public NodeGeneralInfoSection(EditorForm editorForm, boolean hasResourceFileInfo)
	{
		super(editorForm, hasResourceFileInfo);
	}
	
	/**
	 * @see org.eclipse.update.ui.forms.internal.FormSection#dispose()
	 */
	public void dispose()
	{
		super.dispose();
		hostnameText.dispose();
		//setDefaultCheckButton.dispose();
	}	
	
	protected void addSouthControls(Composite parent, FormWidgetFactory formWidgetFactory)
	{		
		super.addSouthControls(parent, formWidgetFactory);
		WidgetFactory widgetFactory = getEditorForm().getWidgetFactory();
		widgetFactory.createLabel(parent, TestUIPlugin.getString("LBL_HOST_NME")); //$NON-NLS-1$
		hostnameText = widgetFactory.createStyledText(parent, SWT.FULL_SELECTION | SWT.SINGLE);
		hostnameText.setLayoutData(GridDataUtil.createHorizontalFill());		
		
		//setDefaultCheckButton = widgetFactory.createButton(parent, "Set as the default", SWT.CHECK);
		//setDefaultCheckButton.addSelectionListener(this);		
	}
	
	public void setEditable(boolean isEditable)
	{
		super.setEditable(isEditable);
		if(hostnameText != null)
			hostnameText.setEditable(isEditable);
		//if(setDefaultCheckButton != null)
			//setDefaultCheckButton.setEnabled(isEditable);
	}	
	
	/**
	 * @see org.eclipse.hyades.test.ui.internal.editor.form.base.BaseEditorSection#setInput(java.lang.Object)
	 */
	public void setInput(Object object)
	{	
		super.setInput(object);
		
		hostnameText.removeModifyListener(this);
		String hostname = null;		
		// TODO replace with CMNNode when available
		if(getNamedElement() instanceof CMNNodeInstance)
		{
			hostname = ((CMNNodeInstance)getNamedElement()).getHostname();
			hostname = (hostname == null) ? "" : hostname; //$NON-NLS-1$
			hostnameText.setText(hostname);
		}
		else if(getNamedElement() instanceof CMNNodeType)
		{
			hostname = ((CMNNodeType)getNamedElement()).getHostname();
			hostname = (hostname == null) ? "" : hostname; //$NON-NLS-1$
			hostnameText.setText(hostname);
		}
		hostnameText.addModifyListener(this);		
	}
	
	/**
	 * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
	 */
	public void modifyText(ModifyEvent e)
	{
		super.modifyText(e);
		if(e.widget == hostnameText)
		{
			if(getNamedElement() instanceof CMNNodeInstance)
				((CMNNodeInstance)getNamedElement()).setHostname(hostnameText.getText());
			else if(getNamedElement() instanceof CMNNodeType)
				((CMNNodeType)getNamedElement()).setHostname(hostnameText.getText());
			getEditorForm().getBaseEditorExtension().markDirty();
		}
	}
}

==> hyades.source_3.0.1.1_20041013_1609.zip: org/eclipse/hyades/test/ui/internal/editor/form/util/NodeGeneralInfoSection.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.internal.editor.form.util;

import org.eclipse.hyades.models.common.common.CMNNodeInstance;
import org.eclipse.hyades.models.common.common.CMNNodeType;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.test.ui.editor.form.util.EditorForm;
import org.eclipse.hyades.test.ui.editor.form.util.WidgetFactory;
import org.eclipse.hyades.test.ui.internal.editor.form.base.FormWidgetFactory;
import org.eclipse.hyades.ui.internal.util.GridDataUtil;
import org.eclipse.swt.SWT;
import org.eclipse.swt.accessibility.AccessibleAdapter;
import org.eclipse.swt.accessibility.AccessibleEvent;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.widgets.Composite;

/**
 * This class implements a general infomation section of an {@link org.eclipse.hyades.models.common.configuration.CFGLocation} 
 * resource editor that provides an editing field for <i>hostname</i>.
 *  
 * @author bjiang
 * @since  1.3
 */
public class NodeGeneralInfoSection extends GeneralInfoSection //implements SelectionListener
{
	private StyledText hostnameText;
	//private Button	setDefaultCheckButton;
	
	/**
	 * @param editorForm
	 */
	public NodeGeneralInfoSection(EditorForm editorForm, boolean hasResourceFileInfo)
	{
		super(editorForm, hasResourceFileInfo);
	}
	
	/**
	 * @see org.eclipse.update.ui.forms.internal.FormSection#dispose()
	 */
	public void dispose()
	{
		super.dispose();
		hostnameText.dispose();
		//setDefaultCheckButton.dispose();
	}	
	
	protected void addSouthControls(Composite parent, FormWidgetFactory formWidgetFactory)
	{		
		super.addSouthControls(parent, formWidgetFactory);
		WidgetFactory widgetFactory = getEditorForm().getWidgetFactory();
		widgetFactory.createLabel(parent, TestUIPlugin.getString("LBL_HOST_NME")); //$NON-NLS-1$
		hostnameText = widgetFactory.createStyledText(parent, SWT.FULL_SELECTION | SWT.SINGLE);
		hostnameText.setLayoutData(GridDataUtil.createHorizontalFill());	
		hostnameText.getAccessible().addAccessibleListener(new AccessibleAdapter() {
			public void getName(AccessibleEvent e) {
				e.result = TestUIPlugin.getString("W_HOST_NME");
			}
		});
		
		//setDefaultCheckButton = widgetFactory.createButton(parent, "Set as the default", SWT.CHECK);
		//setDefaultCheckButton.addSelectionListener(this);		
	}
	
	public void setEditable(boolean isEditable)
	{
		super.setEditable(isEditable);
		if(hostnameText != null)
			hostnameText.setEditable(isEditable);
		//if(setDefaultCheckButton != null)
			//setDefaultCheckButton.setEnabled(isEditable);
	}	
	
	/**
	 * @see org.eclipse.hyades.test.ui.internal.editor.form.base.BaseEditorSection#setInput(java.lang.Object)
	 */
	public void setInput(Object object)
	{	
		super.setInput(object);
		
		hostnameText.removeModifyListener(this);
		String hostname = null;		
		// TODO replace with CMNNode when available
		if(getNamedElement() instanceof CMNNodeInstance)
		{
			hostname = ((CMNNodeInstance)getNamedElement()).getHostname();
			hostname = (hostname == null) ? "" : hostname; //$NON-NLS-1$
			hostnameText.setText(hostname);
		}
		else if(getNamedElement() instanceof CMNNodeType)
		{
			hostname = ((CMNNodeType)getNamedElement()).getHostname();
			hostname = (hostname == null) ? "" : hostname; //$NON-NLS-1$
			hostnameText.setText(hostname);
		}
		hostnameText.addModifyListener(this);		
	}
	
	/**
	 * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
	 */
	public void modifyText(ModifyEvent e)
	{
		super.modifyText(e);
		if(e.widget == hostnameText)
		{
			if(getNamedElement() instanceof CMNNodeInstance)
				((CMNNodeInstance)getNamedElement()).setHostname(hostnameText.getText());
			else if(getNamedElement() instanceof CMNNodeType)
				((CMNNodeType)getNamedElement()).setHostname(hostnameText.getText());
			getEditorForm().getBaseEditorExtension().markDirty();
		}
	}
}
